@@ -5,7 +5,8 @@ NULL
 #'
 #' @keywords internal
 #' @export
-setClass("PqConnection",
+setClass(
+  "PqConnection",
   contains = "DBIConnection",
   slots = list(
     ptr = "externalptr",
@@ -38,12 +39,23 @@ format.PqConnection <- function(x, ...) {
 }
 
 get_data_type <- function(obj) {
-  if (is.factor(obj)) return("TEXT")
-  if (inherits(obj, "POSIXt")) return("TIMESTAMPTZ")
-  if (inherits(obj, "Date")) return("DATE")
-  if (inherits(obj, "difftime")) return("TIME")
-  if (inherits(obj, "integer64")) return("BIGINT")
-  switch(typeof(obj),
+  if (is.factor(obj)) {
+    return("TEXT")
+  }
+  if (inherits(obj, "POSIXt")) {
+    return("TIMESTAMPTZ")
+  }
+  if (inherits(obj, "Date")) {
+    return("DATE")
+  }
+  if (inherits(obj, "difftime")) {
+    return("TIME")
+  }
+  if (inherits(obj, "integer64")) {
+    return("BIGINT")
+  }
+  switch(
+    typeof(obj),
     integer = "INTEGER",
     double = "DOUBLE PRECISION",
     character = "TEXT",
@@ -64,9 +76,13 @@ check_tz <- function(timezone) {
     },
     error = function(e) {
       warning(
-        "Invalid time zone '", timezone, "', ",
+        "Invalid time zone '",
+        timezone,
+        "', ",
         "falling back to local time.\n",
-        "Set the `", arg_name, "` argument to a valid time zone.\n",
+        "Set the `",
+        arg_name,
+        "` argument to a valid time zone.\n",
         conditionMessage(e),
         call. = FALSE
       )
@@ -139,7 +155,8 @@ postgresIsTransacting <- function(conn) {
 
 #' Imports a large object from file
 #'
-#' Returns an object idenfier (Oid) for the imported large object
+#' Returns an object identifier (Oid) for the imported large object.
+#' This function must be called within a transaction.
 #'
 #' @export
 #' @param conn a [PqConnection-class] object, produced by
@@ -156,15 +173,67 @@ postgresIsTransacting <- function(conn) {
 #' })
 #' }
 postgresImportLargeObject <- function(conn, filepath = NULL, oid = 0) {
-
   if (!postgresIsTransacting(conn)) {
     stopc("Cannot import a large object outside of a transaction")
   }
 
-  if (is.null(filepath)) stopc("'filepath' cannot be NULL")
-  if (is.null(oid)) stopc("'oid' cannot be NULL")
-  if (is.na(oid)) stopc("'oid' cannot be NA")
-  if (oid < 0) stopc("'oid' cannot be negative")
+  if (is.null(filepath)) {
+    stopc("'filepath' cannot be NULL")
+  }
+  if (is.null(oid)) {
+    stopc("'oid' cannot be NULL")
+  }
+  if (is.na(oid)) {
+    stopc("'oid' cannot be NA")
+  }
+  if (oid < 0) {
+    stopc("'oid' cannot be negative")
+  }
 
   connection_import_lo_from_file(conn@ptr, filepath, oid)
 }
+
+#' Exports a large object to file
+#'
+#' Exports a large object from the database to a file on disk. This function
+#' uses PostgreSQL's `lo_export()` function which efficiently streams the data
+#' directly to disk without loading it into memory, making it suitable for
+#' very large objects (GB+) that would cause memory issues with `lo_get()`.
+#' This function must be called within a transaction.
+#'
+#' @export
+#' @param conn a [PqConnection-class] object, produced by
+#'   [DBI::dbConnect()]
+#' @param oid the object identifier (Oid) of the large object to export
+#' @param filepath a path where the large object should be exported
+#' @return invisible NULL on success, or stops with an error
+#' @examples
+#' \dontrun{
+#' con <- postgresDefault()
+#' filepath <- 'your_image.png'
+#' dbWithTransaction(con, {
+#'   oid <- postgresImportLargeObject(con, filepath)
+#' })
+#' # Later, export the large object back to a file
+#' dbWithTransaction(con, {
+#'   postgresExportLargeObject(con, oid, 'exported_image.png')
+#' })
+#' }
+postgresExportLargeObject <- function(conn, oid, filepath) {
+  if (!postgresIsTransacting(conn)) {
+    stopc("Cannot export a large object outside of a transaction")
+  }
+
+  if (is.null(oid)) {
+    stopc("'oid' cannot be NULL")
+  }
+  if (is.na(oid)) {
+    stopc("'oid' cannot be NA")
+  }
+  if (oid < 0) {
+    stopc("'oid' cannot be negative")
+  }
+
+  connection_export_lo_to_file(conn@ptr, oid, filepath)
+  invisible()
+}
