@@ -6,7 +6,9 @@
 #' @rdname dbDataType
 #' @usage NULL
 dbDataType_PqDriver <- function(dbObj, obj, ...) {
-  if (is.data.frame(obj)) return(vapply(obj, dbDataType, "", dbObj = dbObj))
+  if (is.data.frame(obj)) {
+    return(vapply(obj, dbDataType, "", dbObj = dbObj))
+  }
   get_data_type(obj)
 }
 
