@@ -3,7 +3,9 @@
 #' @rdname postgres-tables
 #' @usage NULL
 sqlData_PqConnection <- function(con, value, row.names = FALSE, ...) {
-  if (is.null(row.names)) row.names <- FALSE
+  if (is.null(row.names)) {
+    row.names <- FALSE
+  }
   value <- sqlRownamesToColumn(value, row.names)
 
   value[] <- lapply(value, dbQuoteLiteral, conn = con)
