@@ -11,11 +11,14 @@ class PqColumnDataSourceFactory : public DbColumnDataSourceFactory {
   const std::vector<DATA_TYPE> types;
 
 public:
-  PqColumnDataSourceFactory(PqResultSource* result_source_, const std::vector<DATA_TYPE>& types_);
+  PqColumnDataSourceFactory(
+    PqResultSource* result_source_,
+    const std::vector<DATA_TYPE>& types_
+  );
   virtual ~PqColumnDataSourceFactory();
 
 public:
   virtual DbColumnDataSource* create(const int j);
 };
 
-#endif //RPOSTGRES_PQCOLUMNDATASOURCEFACTORY_H
+#endif  // RPOSTGRES_PQCOLUMNDATASOURCEFACTORY_H
